.. _getting_started_ref:

***************
Getting started
***************

Installation
------------

.. grid:: 2

    .. grid-item-card::

        Working with conda?
        ^^^^^^^^^^^^^^^^^^^

        SciPy is part of the `Anaconda <https://docs.continuum.io/anaconda/>`__
        distribution and can be installed with Anaconda or Miniconda:

        ++++++++++++++++++++++

        .. code-block:: bash

            conda install scipy

    .. grid-item-card::

        Prefer pip?
        ^^^^^^^^^^^

        SciPy can be installed via pip from `PyPI <https://pypi.org/project/scipy>`__.

        ++++

        .. code-block:: bash

            pip install scipy

    .. grid-item-card::
        :columns: 12

        In-depth instructions?
        ^^^^^^^^^^^^^^^^^^^^^^

        Installing a specific version? Installing from source? Check the
        installation page.

        .. container:: custom-button

            `Learn more <https://scipy.org/install/>`__

Tutorials
---------

For a quick overview of SciPy functionality, see the :ref:`user guide<user_guide>`.

You can also refer to the :ref:`reference guide<scipy-api>` for an exhaustive
list of all what is possible with SciPy.
